#!/bin/bash

#
# packager         : sebastian <zenwalkuser> seb@seb2.dyndns.org
#
# source location  : http://uim.googlecode.com/files/uim-1.5.1.tar.gz 
#
#
# last revised     : 02/05/2010
#
# additional files : anthy and japanese sazanami TTF fonts required
#

_error() {
  echo -e $1
  echo -e "\nSee $soft-install.log for errors"
  exit 1
}

soft='uim'
softversion='1.5.7'
packageversion='64.1'

arch='i486'
cpu='i686'
makeopts='-j2'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
srcuri="http://uim.googlecode.com/files/$soft-$softversion.tar.gz"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

echo "------------------------------------------------"
echo "Build package: $soft $softversion"
echo "------------------------------------------------"

cd $buildir
rm -rf $src
if [ ! -f $srcpkg ]; then
  echo "- Download source..."
  wget --passive --quiet $srcuri || _error "\tDownload failed!"
fi 
echo "- Unpacking source..."
tar -xzf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS=$CFLAGS

cd $src
chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

echo "- Configuring package..."
cd $src
    ./configure --prefix=/usr \
    --sysconfdir=/etc \
    --mandir=/usr/man \
    --localstatedir=/var > ../$soft-install.log

echo "- Compiling package..."
make $makeopts >> ../$soft-install.log 2>&1 || _error "\tCompile failed"
echo "- Install package from temp directory"
make install DESTDIR=$dest >> ../$soft-install.log

echo "- Stripped all binaries and gzipping man pages..."
( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

echo "- Copying documentation..."
mkdir -p $dest/usr/doc/$soft-$softversion
cp -af \
  AUTHORS COPYING INSTALL NEWS README RELNOTE ChangeLog* $dest/usr/doc/$soft-$softversion


#Create a proper desktop file
rm -rf $dest/usr/share/applications/*
cat <<EOF > $dest/usr/share/applications/uim.desktop
[Desktop Entry]
Type=Application
Encoding=UTF-8
Name=Input Method (uim)
Name[ja]=入力メソッド (uim)
Name[ko]=입력기 (uim)
Comment=Customize uim input method environment
Comment[ja]=入力メソッド環境 (uim) を設定します
Comment[ko]=uim 환경설정
Exec=uim-pref-gtk
Icon=uim-icon
Terminal=false
Categories=Settings;
EOF

mkdir -p $dest/install
cat > $dest/install/slack-desc <<END
   |-----handy-ruler------------------------------------------------------|
$soft: uim - the universal input method
$soft:
$soft: uim ist the universal input method
$soft: to support input of different languages
$soft: this version is build for the use with
$soft: the anthy conversion engine to support
$soft: japanese language input
$soft:
$soft: 
$soft:
$soft: 
END

mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir
cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/
)

#
# update the gtk.immodules
#
cat << "EOF" > $dest/install/doinst.sh
if [ -x usr/bin/gtk-query-immodules-2.0 ]; then
  GTK_PATH=${ROOT}/usr/lib/gtk-2.0/ usr/bin/gtk-query-immodules-2.0 > etc/gtk-2.0/gtk.immodules
fi
EOF


#
# create some folders and icon symlinks
#
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps/
cd $dest/usr/share/icons/hicolor/48x48/apps/ 
ln -s ../../../../uim/pixmaps/uim-icon48.png uim-icon.png
cd $dest/usr/share/icons/hicolor/64x64/apps/
ln -s ../../../../uim/pixmaps/uim-icon64.png uim-icon.png


cd $dest


#Removing empty folders
rmdir $dest/usr/include/libgcroots
rmdir $dest/usr/include/sigscheme
rmdir $dest/usr/lib/uim/notify
rmdir $dest/usr/share/doc/sigscheme
rmdir $dest/usr/share/doc


# creating package
echo "- Creating $soft package..."
makepkg -l y -c y $dest.txz > /dev/null 2>&1
cd $buildir
md5sum $package.txz > $dest.md5

echo "- Deleting temporary directory's..."
rm -rf $src
rm -rf $dest

echo "Package created complete."
exit 0
